"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ec2CdkStack = void 0;
const ec2 = __importStar(require("aws-cdk-lib/aws-ec2"));
const cdk = __importStar(require("aws-cdk-lib"));
const iam = __importStar(require("aws-cdk-lib/aws-iam"));
const KeyPair = __importStar(require("cdk-ec2-key-pair"));
const aws_s3_assets_1 = require("aws-cdk-lib/aws-s3-assets");
class Ec2CdkStack extends cdk.Stack {
    constructor(scope, id, props, options) {
        super(scope, id, props);
        const key = new KeyPair.KeyPair(this, `${id}KeyPair`, {
            name: `${id}-keypair`,
            description: 'Key Pair created with CDK Deployment'
        });
        const vpc = new ec2.Vpc(this, `${id}VPC`, Object.assign({ natGateways: 0, subnetConfiguration: [
                {
                    cidrMask: 24,
                    name: 'asterisk',
                    subnetType: ec2.SubnetType.PUBLIC
                }
            ] }, (options.vpcProps || {})));
        const securityGroup = new ec2.SecurityGroup(this, `${id}SecurityGroup`, Object.assign({ vpc, description: 'Allow SSH (TCP port 22) in', allowAllOutbound: true }, (options.securityGroupProps || {})));
        (options.allowPorts || [22, 80, 443]).forEach((port) => {
            securityGroup.addIngressRule(ec2.Peer.anyIpv4(), ec2.Port.tcp(port), `Allow ${port}`);
        });
        const role = new iam.Role(this, `${id}Ec2Role`, {
            assumedBy: new iam.ServicePrincipal('ec2.amazonaws.com')
        });
        role.addManagedPolicy(iam.ManagedPolicy.fromAwsManagedPolicyName('AmazonSSMManagedInstanceCore'));
        const ami = new ec2.GenericLinuxImage({
            // Amazon Linux 2 Kernel 5.10 AMI 2.0.20220719.0 x86_64 HVM gp2
            'us-east-1': options.image || 'ami-090fa75af13c156b4'
        });
        const ec2Instance = new ec2.Instance(this, `${id}Instance`, Object.assign({ vpc, instanceType: ec2.InstanceType.of(ec2.InstanceClass.T2, ec2.InstanceSize.MICRO), machineImage: ami, securityGroup: securityGroup, keyName: key.keyPairName, role: role, instanceName: `${id}Ec2Instance` }, (options.ec2Props || {})));
        if (options.userDataPath) {
            // Create an asset that will be used as part of User Data to run on first load
            const asset = new aws_s3_assets_1.Asset(this, `${id}Asset`, {
                path: options.userDataPath
            });
            const localPath = ec2Instance.userData.addS3DownloadCommand({
                bucket: asset.bucket,
                bucketKey: asset.s3ObjectKey
            });
            ec2Instance.userData.addExecuteFileCommand({
                filePath: localPath,
                arguments: '--verbose -y'
            });
            asset.grantRead(ec2Instance.role);
        }
        // Create outputs for connecting
        new cdk.CfnOutput(this, 'IP Address', {
            value: ec2Instance.instancePublicIp
        });
        new cdk.CfnOutput(this, 'Key Name', { value: key.keyPairName });
        new cdk.CfnOutput(this, 'Download Key Command', {
            value: `aws secretsmanager get-secret-value --secret-id ec2-ssh-key/${id}-keypair/private --query SecretString --output text > cdk-key.pem && chmod 400 cdk-key.pem`
        });
        new cdk.CfnOutput(this, 'ssh command', {
            value: 'ssh -i cdk-key.pem -o IdentitiesOnly=yes ec2-user@' +
                ec2Instance.instancePublicIp
        });
    }
}
exports.Ec2CdkStack = Ec2CdkStack;
